==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/extnet/data_extnet_list/main.tf <==
/*
Пример использования
Получение списка сетей
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_extnet_list" "el" {
  #id аккаунта для фильтрации результата
  #необязательный параметр
  #тип - целое число
  #account_id = 1111111

  #фильтр по id внешней сети
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени внешней сети
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #network = "test"

  #фильтр по id vlan
  #опциональный параметр
  #тип - целое число
  #vlan_id = 100

  #фильтр по id vnfDevices
  #опциональный параметр
  #тип - целое число
  #vnfdev_id = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_extnet_list.el
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/extnet/data_extnet_list/main.tf <==
/*
Пример использования
Получение списка сетей
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "dynamix_extnet_list" "el" {
  #id аккаунта для фильтрации результата
  #необязательный параметр
  #тип - целое число
  #account_id = 1111111

  #фильтр по id внешней сети
  #опциональный параметр
  #тип - целое число
  #by_id = 100

  #фильтр по имени внешней сети
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по IP внешней сети
  #опциональный параметр
  #тип - строка
  #network = "test"

  #фильтр по id vlan
  #опциональный параметр
  #тип - целое число
  #vlan_id = 100

  #фильтр по id vnfDevices
  #опциональный параметр
  #тип - целое число
  #vnfdev_id = 100

  #фильтр по статусу
  #опциональный параметр
  #тип - строка
  #status = "ENABLED"

  #сортировка по одному из поддерживаемых полей
  #опциональный параметр
  #тип - строка
  #формат - "+поле" по возрастанию / "-поле" по убыванию
  #sort_by = "+name"

  #кол-во страниц для вывода
  #опицональный параметр 
  #тип - целое число
  #page = 1

  #размер страницы
  #опицональный параметр 
  #тип - целое число
  #size = 1
}

output "test" {
  value = data.dynamix_extnet_list.el
}
